
@BOTTOM@

/* */
#undef HAVE_TYPEOF

/* */
#undef HAVE_LONG_LONG

/* */
#undef HAVE_POINTER_COMPARISON_BUG

/* */
#undef HAVE_MAXINT_CONVERSION_BUG

/* */
#undef HAVE_SOCKLEN_T

/* */
#undef HAVE_VOLATILE

/* */
#undef HAVE_ERRNO

/* */
#undef RENAME_OVER_EXISTING_FILES

/* */
#undef HAVE_STRLEN

/* */
#undef HAVE_STRCPY

/* */
#undef HAVE_STRCHR

/* */
#undef HAVE_STRRCHR

/* */
#undef HAVE_STRCMP

/* */
#undef HAVE_STRNCMP

/* */
#undef HAVE_STRCASECMP

/* */
#undef HAVE_STRNCASECMP

/* */
#undef HAVE_STRCSPN

/* */
#undef HAVE_STRSPN

/* */
#undef HAVE_STRSTR

/* */
#undef HAVE_MEMCMP

/* */
#undef HAVE_MEMCHR

/* */
#undef HAVE_MEMCPY

/* */
#undef HAVE_MEMMOVE

/* */
#undef HAVE_MEMSET

/* */
#undef HAVE_STRERROR

/* */
#undef HAVE_GETHOSTBYNAME

/* */
#undef HAVE_GETHOSTBYNAME_BUG

/* */
#undef HAVE_BEGINTHREAD

/* */
#undef HAVE_PTHREADS

/* */
#undef X2

/* */
#undef HAVE_SSL

